Notes
=====

Not clear whether the freebayes_1.3.7 version works.
Version 1.2.0 works and is used in sequana variant calling pipeline.
Version 1.3.7 works but vcfuniq has a lib symbol issue (for freebayes parallel)
For version 1.3.9 using micromamba, even freebayes does not work so we created our own recipe.
